@@ -13,7 +13,7 @@ from deployv.helpers import utils
 logger = logging.getLogger(__name__)  # pylint: disable=C0103
 
 
-class PostgresConnector(object):
+class PostgresConnector:
     """A simple helper to perform a postgres connection and execute simple sql sentences.
     """
 
@@ -41,6 +41,8 @@ class PostgresConnector(object):
                 self.__conn.set_isolation_level(0)
             self.__cursor = self.__conn.cursor(
                 cursor_factory=psycopg2.extras.DictCursor)
+        except (KeyboardInterrupt, errors.GracefulExit):
+            raise
         except Exception as error:
             # TODO: log this then raise
             logger.debug(
@@ -49,7 +51,7 @@ class PostgresConnector(object):
             self.disconnect()
             raise
 
-    def execute(self, sql_str, *args):
+    def execute(self, sql_str, *args, **kwargs):
         """This method basically wraps *execute* cursor method from psycopg2.
 
         See `passing parameters to sql
@@ -64,16 +66,21 @@ class PostgresConnector(object):
         :returns: A dict if a select was performed. Bool if update/insert.
         :rtype: dict or bool
         """
+        raw = kwargs.pop('raw', False)
         change = sql_str.lower().startswith((
             'insert into', 'update', 'create', 'delete', 'alter', 'reassign', 'grant'))
         try:
             logger.debug('SQL: %s', sql_str)
             self.__cursor.execute(sql_str, *args)
+        except (KeyboardInterrupt, errors.GracefulExit):
+            raise
         except Exception:
             self.__conn.rollback()
             raise
         if change:
             self.__conn.commit()
+        if raw:
+            return self.__cursor.fetchall()
         return utils.copy_list_dicts(self.__cursor) if not change else True
 
     def check_config(self):
@@ -86,6 +93,8 @@ class PostgresConnector(object):
             logger.debug('')
             res = self.execute("select version();")
             logger.debug('Postgres returned: %s', res)
+        except (KeyboardInterrupt, errors.GracefulExit):
+            raise
         except Exception as error:  # pylint: disable=W0703
             logger.error('PostgreSQL connection test failed %s',
                          str(error))
@@ -110,7 +119,7 @@ class PostgresConnector(object):
         return self
 
 
-class PostgresShell(object):
+class PostgresShell:
     """This class is used to perform some Postgres operations that generally are done in the
     console.
 
@@ -171,6 +180,7 @@ class PostgresShell(object):
         sql = (("SELECT pg_terminate_backend(pid) from pg_stat_activity "
                "WHERE pid <> pg_backend_pid() AND datname = '{dbname}'")
                .format(dbname=db_name))
+        logger.info('Terminating sessions in the db %s', db_name)
         try:
             with PostgresConnector(config) as db:
                 db.execute(sql)
@@ -320,10 +330,10 @@ class PostgresShell(object):
             error_msg = utils.get_error_message(error)
             allowed_errors = ['permission denied to create extension',
                               'password authentication failed']
-            if 'extension "unaccent" already exists' in error_msg:
+            if '"unaccent" already exists' in error_msg:
                 logger.info(error_msg.strip())
                 return
-            elif any(err in error_msg for err in allowed_errors):
+            if any(err in error_msg for err in allowed_errors):
                 logger.error(
                     'Unable to create the unaccent extension, authentication for the'
                     ' postgres user in the deployv.conf file failed or the'
