@@ -5,7 +5,7 @@ import click
 from pkg_resources import working_set
 import deployv
 from deployv.base import commandv
-from deployv.helpers import utils, build_helper, configuration_helper, json_helper
+from deployv.helpers import utils, configuration_helper, json_helper
 from deployv.instance import instancev
 import os
 import re
@@ -70,7 +70,7 @@ class DeployvCLI(click.MultiCommand):
             if doc and not kwargs.get('help'):
                 kwargs['help'] = doc
             if doc and not kwargs.get('short_help'):
-                kwargs['short_help'] = doc if len(doc) <= 50 else doc[:50]+'...'
+                kwargs['short_help'] = doc if len(doc) <= 50 else doc[:50] + '...'
                 kwargs['short_help'] = doc
 
             def decorator():
@@ -83,6 +83,7 @@ class DeployvCLI(click.MultiCommand):
     def add_command(self, name, function):
         self._cmds[name] = function
 
+
 cli = DeployvCLI()  # pylint: disable=C0103
 
 
@@ -179,10 +180,9 @@ def backupdb(ctx, config_file, backup_dir, reason, tmp_dir, database, cformat,
     if not config_dict:
         sys.exit(1)
     group_config = {'cformat': cformat, 'reason': reason, 'prefix': prefix,
-                    'backup_src': backup_dir, 'temp_folder': tmp_dir}
+                    'backup_src': backup_dir, 'temp_folder': tmp_dir, 'jobs': jobs}
     for param, value in group_config.items():
         config_dict.get('group_config').update({param: value} if value else {})
-    config_dict['container_config'].update({'jobs': jobs} if jobs else {})
     config_dict['instance']['config'].update({'db_name': database} if database else {})
     config_obj.generate_configuration(config_dict)
     command = commandv.CommandV(config_obj)
@@ -273,7 +273,7 @@ def update(ctx, config_file, database):
     config_dict.get('group_config').update({'command': 'deployvcmd.commandv.updatedb'})
     config_obj.generate_configuration(config_dict)
     command = commandv.CommandV(config_obj)
-    command.update_trigger()
+    command.create_trigger()
 
 
 @cli.command()
@@ -387,6 +387,11 @@ def build(ctx, config_file, repo, branch, image_name, working_folder,
           version, force, odoo_repo, tag, skip_push):
     config_obj = ctx.parent.command.config_parser
     config_dict = utils.merge_config(config_file or {})
+    variables = {}
+    if version:
+        variables.update({'version': version})
+    if image_name:
+        variables.update({'base_image': image_name})
     if not config_dict:
         sys.exit(1)
     if repo and not version or version and not repo:
@@ -396,22 +401,19 @@ def build(ctx, config_file, repo, branch, image_name, working_folder,
     if branch and not repo:
         logger.error('If you specify a branch you have to specify the repo')
         sys.exit(1)
-    if not branch:
-        branch = version
+    branch = branch or version
     if repo and branch:
         repo_name = repo.split('/')[-1].split('.')[0]
         repo_path = os.path.join('extra_addons', repo_name)
-        config_dict = build_helper.add_repo(config_dict, branch, repo_name, repo_path, repo)
+        utils.add_repo(branch, repo_name, repo_path, repo, config=config_dict,
+                       extra={'main_repo': True})
     if odoo_repo:
         if not re.search('.*/.*#.*', odoo_repo):
             logger.error('The specified odoo repo does not have the correct format.'
                          ' Example format: odoo/odoo#8.0')
             sys.exit(1)
         parts = odoo_repo.split('#', 1)
-        odoo_branch = parts[1]
-        odoo_url = 'https://github.com/{repo}.git'.format(repo=parts[0])
-        config_dict = build_helper.add_repo(config_dict, odoo_branch, 'odoo', 'odoo', odoo_url)
-    config_dict.get('container_config').update({'base_image_name': image_name})
+        variables.update({'odoo_repo': parts[0], 'odoo_branch': parts[1]})
     if not config_dict.get('instance').get('config').get('db_owner'):
         config_dict.get('instance').get('config').update({
             'db_owner': config_obj.postgres.get('db_user')
@@ -420,11 +422,12 @@ def build(ctx, config_file, repo, branch, image_name, working_folder,
         config_dict.get('instance').get('config').update({
             'db_owner_passwd': config_obj.postgres.get('db_password')
         })
-    config_dict.get('container_config').update({'build_image': True})
+    config_dict.get('container_config').update({
+        'build_image': True, 'working_folder': working_folder})
     config_dict.get('group_config').update({
-        'working_folder': working_folder, 'version': version,
-        'force': force, 'tag': tag, 'skip_push': skip_push
+        'version': version, 'force': force, 'tag': tag, 'skip_push': skip_push
     })
+    config_dict.get("container_config").get("env_vars").update(variables)
     config_obj.generate_configuration(config_dict)
     command = commandv.CommandV(config_obj)
     command.build_image_trigger()
@@ -494,7 +497,7 @@ def update_production(ctx, config_file, container, db_name, db_user, db_password
         'db_password': db_password or json_db_config.get('db_password'),
         'db_host': db_host or json_db_config.get('db_host'),
         'db_port': db_port or json_db_config.get('db_port'),
-        'dbfilter': db_name or json_db_config.get('db_name'),
+        'dbfilter': False,
     }
     if not all(db_config.values()):
         logger.error('Production database configuration is incomplete. '
