@@ -9,11 +9,11 @@ from datetime import datetime
 logger = logging.getLogger(__name__)  # pylint: disable=C0103
 
 
-class SenderMessage(object):
+class SenderMessage:
 
     def __init__(self, config):
         self.__config = config
-        rabbit_obj = rabbitv.FileRabbitConfiguration(self.__config, result=True)
+        rabbit_obj = rabbitv.FileRabbitConfiguration(self.__config, 'result')
         self._rabbit_sender = senderv.RabbitSenderV(
             rabbit_obj, self.__config.deployer.get('node_id'))
 
@@ -54,7 +54,7 @@ class SenderMessage(object):
             })
         message.set_message_body(message_body, message_type='result')
         if not message.receiver_node_id:
-            logger.warning('Failed to send the message: The receiver is required')
+            logger.debug('Failed to send the message: The receiver is required')
             return
         try:
             self._rabbit_sender.send_message(message)
