@@ -5,6 +5,8 @@ import base64
 from datetime import datetime
 import uuid
 from deployv.helpers import json_helper, utils, configuration_helper
+from deployv.base.errors import GracefulExit
+from deployv.instance.instancev import DummyInstanceV
 import simplejson as json
 import time
 import logging
@@ -16,9 +18,11 @@ except ImportError:
 
 _logger = logging.getLogger('deployv')
 TRIGGER_MAPPINGS = {
+    'reload_config': 'reload_config_trigger',
     'build_image': 'build_image_trigger',
     'create': 'create_trigger',
-    'update_instance': 'update_trigger',
+    'commit_history': 'commit_history_trigger',
+    'update_instance': 'create_trigger',
     'restart_instance': 'instance_restart_trigger',
     'restart_container': 'container_restart_trigger',
     'change_passwords': 'change_passwords_trigger',
@@ -30,11 +34,12 @@ TRIGGER_MAPPINGS = {
 }
 
 
-class BaseWorker(object):
+class BaseWorker:
 
     def __init__(self, configuration_object, sender_class, receiver_class, worker_id):
         self.config_obj = configuration_object.config
         self._wid = worker_id
+        self._wtype = configuration_object.wtype
         self.count = 0
         self._config_class = self.config_obj
         self._receiver = receiver_class(configuration_object,
@@ -87,9 +92,9 @@ class BaseWorker(object):
         _logger.info('Executing rpc for message in worker %s', self._wid)
         _logger.debug('%s worker received "%s"', self._wid,
                       json.dumps(message.original_message, sort_keys=True, indent=4))
-        if message.receiver_node_id != self.config_obj.deployer.get('node_id'):
-            _logger.error('Message in the wrong queue, does not match my wid: %s',
-                          self.config_obj.deployer.get('node_id'))
+        node_id = self.config_obj.deployer.get('node_id')
+        if self._wtype != 'commit' and message.receiver_node_id != node_id:
+            _logger.error('Message in the wrong queue, does not match my wid: %s', node_id)
             return False
         self._sender.send_message(message.get_ack_message())
         _logger.debug('Ack sent')
@@ -117,7 +122,7 @@ class BaseWorker(object):
             'use_nginx': self.config_obj.deployer.get('use_nginx'),
             'nginx_folder': self.config_obj.deployer.get('nginx_folder'),
             'res_id': message.res_id,
-            'sender_node_id': message.receiver_node_id,
+            'sender_node_id': message.receiver_node_id or node_id,
             'deploy_id': message.deploy_id,
             'receiver_node_id': message.sender_node_id,
             'res_model': message.res_model,
@@ -137,10 +142,12 @@ class BaseWorker(object):
             'command': command_name,
             'module': module,
         }
+        instance_class = DummyInstanceV if self._wtype == 'commit' else False
         if module == 'commandv':
             module_base = __import__('deployv.base', fromlist=[str(module)])
             module_command = getattr(module_base, module)
-            command_obj = getattr(module_command, classes.get(module))(command_config)
+            command_obj = getattr(module_command, classes.get(module))(
+                command_config, instance_class)
             _logger.debug('Parameters: %s',
                           json.dumps(parameters, sort_keys=True, indent=4))
             trigger = TRIGGER_MAPPINGS.get(command_name)
@@ -155,19 +162,16 @@ class BaseWorker(object):
             try:
                 starting_trigger()
             except Exception as error:  # pylint: disable=W0703
-                error_msg = utils.get_error_message(error)
-                _logger.exception(error_msg)
-                command_obj.sender.send_message(error_msg, log_type='ERROR')
-                message_body.update(({'error': error_msg}))
-                message.set_message_body(message_body, message_type='error')
-                response = message.build_message()
-                _logger.debug('Message to send %s',
-                              json.dumps(response, sort_keys=True, indent=4))
-                self._sender.send_message(response)
+                message_body.update(({'error': utils.get_error_message(error)}))
+                command_obj.send_message_error(message_body)
+                command_obj.clean_working_folders()
+                if isinstance(error, (KeyboardInterrupt, GracefulExit)):
+                    raise
+                _logger.exception(message_body.get('error'))
             _logger.info('%s worker done', self._wid)
 
 
-class BasicMessage(object):
+class BasicMessage:
     """ Basic unit of communication that will be used for remote communications, you need at least
     specify the sender, receiver and a message body (command, error, status, etc)::
 
@@ -296,7 +300,7 @@ class BasicMessage(object):
             res = self._original_message.copy()
         res.update({
             'receiver_node_id': res.get('receiver_node_id'),
-            'sender_node_id':  res.get('sender_node_id') if send_to is None else send_to,
+            'sender_node_id': res.get('sender_node_id') if send_to is None else send_to,
             'res_model': res.get('res_model'),
             'model': res.get('model'),
             'res_id': res.get('res_id'),
@@ -329,7 +333,7 @@ class BasicMessage(object):
         return self.get_message_str()
 
 
-class BaseFileConfig(object):
+class BaseFileConfig:
     def __init__(self, config_file, result=False):
         assert path.isfile(config_file)
         self.config = ConfigParser()
